local addon =
{
	debug = false,
	resetingIgnore = false,
	numToReset = 0,
	currReset = 0,
	namesToRemove = {},
	fnlocals = {},
}
if (addon.debug) then
	ResetIgnoreLocals = addon
end

local function print(str)
	local loc =
	{
		parm = {str = str},
	}
	if (addon.debug) then
		addon.fnlocals.Print = loc
	end

	CHAT_SYSTEM:AddMessage("ResetIgnore: " .. tostring(str))
end

local function trimparm(val)

	local loc =
	{
		parm = {val = val},
		result = val,
		valLen = #val,
		trailing = 0,
	}
	if (addon.debug) then
		addon.fnlocals.trimparm = loc
	end

	while (string.sub(loc.result, #loc.result - loc.trailing, -loc.trailing - 1) == " ") do
		loc.trailing = loc.trailing + 1
	end

	if (loc.trailing > 0) then
		loc.result = string.sub(val, 1, -1 - loc..trailing)
	end

	if (val) then
		if (string.sub(loc.result, 1, 1) == '"' and
		    string.sub(loc.result, #loc.result, -1) == '"') then

			loc.result = string.sub(loc.result, 2, -2)

		elseif (string.sub(loc.result, 1, 1) == "'" and
		         string.sub(loc.result, #loc.result, -1) == "'") then

			loc.result = string.sub(loc.result, 2, -2)

		end
	end

	if (addon.debug and val ~= loc.result) then
		print("[" .. val .. "]" ..
			  " trimmed to " ..
			  "[" .. loc.result .. "]")
	end

	return loc.result
end

local function ignoreremoved()

	local loc =
	{
		parm = {},
	}
	if (addon.debug) then
		addon.fnlocals.OnSlashCommand = loc
	end

	if (addon.resetingIgnore) then
		if (addon.currReset < addon.numToReset) then
			if (not addon.debug) then
				RemoveIgnore(addon.namesToRemove[addon.currReset + 1])
			else
				print(addon.namesToRemove[addon.currReset] .. " removed from ignore list")
			end
			addon.currReset = addon.currReset + 1
		else
			print (addon.numToReset .. " removed from ignore list")
			addon.resetingIgnore = false
			addon.numToReset = 0
			addon.currReset = 0
			addon.namesToRemove = {}
		end
	end
end

local function OnSlashCommand(...)

	local loc =
	{
		parm = {...},
		temp = {},
		removed = {},
		numIgnored = GetNumIgnored(),
	}
	if (addon.debug) then
		addon.fnlocals.OnSlashCommand = loc
	end

	addon.resetingIgnore = false
	addon.numToReset = 0
	addon.currReset = 0
	addon.namesToRemove = {}

	if (loc.parm[1]) then
		loc.parm[1] = trimparm(loc.parm[1])
	end

	if (addon.debug) then
		for i = 1, #loc.parm do
			CHAT_SYSTEM:AddMessage("Arg" .. i .. " - " .. loc.parm[i])
		end
	end

	for i = 1, loc.numIgnored do
		loc.temp[i] = {GetIgnoredInfo(i)}
	end

	if (string.sub(loc.parm[1], 1, 1) == "@") then
		for i = 1, loc.numIgnored do
			if (loc.parm[1] and string.find(loc.temp[i][1], loc.parm[1], 1)) then
				table.insert(addon.namesToRemove, loc.temp[i][1])
			end
		end
	else
		for i = 1, loc.numIgnored do
			if (loc.parm[1] and string.find(loc.temp[i][2], loc.parm[1], 1)) then
				table.insert(addon.namesToRemove, loc.temp[i][1])
			end
		end
	end

	addon.numToReset = #addon.namesToRemove
	if (addon.debug) then
		print (addon.numToReset .. " to remove from ignore list")
		addon.currReset = 1
		addon.resetingIgnore = true
		for i = 1, #addon.namesToRemove do
			ignoreremoved()
		end
	else
		if (addon.numToReset > 0) then
			RemoveIgnore(addon.namesToRemove[1])
			addon.currReset = 1
			addon.resetingIgnore = true
		end
	end
end

local function delaynext()
	zo_callLater(ignoreremoved, 2000)
end

if (not addon.debug) then
	EVENT_MANAGER:RegisterForEvent(addon.Name, EVENT_IGNORE_REMOVED, delaynext)
end

SLASH_COMMANDS["/resetignore"] = function( ... ) OnSlashCommand( ... ) end
SLASH_COMMANDS["/ri"] = function( ... ) OnSlashCommand( ... ) end
